@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2004, 2005, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2004, 2005, 2007,
+   2008 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,22 +19,20 @@
 
 #include "imap4d.h"
 
-/*
- */
-
-/* The CLOSE command permanently removes from the currently selected
-   mailbox all messages that have the \\Deleted flag set, and returns
-   to authenticated state from selected state.  */
-int
-imap4d_close (struct imap4d_command *command, char *arg MU_ARG_UNUSED)
+static int
+imap4d_close0 (struct imap4d_command *command, imap4d_tokbuf_t tok,
+	       int expunge)
 {
   const char *msg = NULL;
   int status, flags;
+
+  if (imap4d_tokbuf_argc (tok) != 2)
+    return util_finish (command, RESP_BAD, "Invalid arguments");
   
   mu_mailbox_get_flags (mbox, &flags);
   if ((flags & MU_STREAM_READ) == 0)
     {
-      status = mu_mailbox_flush (mbox, 1);
+      status = mu_mailbox_flush (mbox, expunge);
       if (status)
 	{
 	  mu_diag_output (MU_DIAG_ERROR,
@@ -47,7 +46,8 @@ imap4d_close (struct imap4d_command *command, char *arg MU_ARG_UNUSED)
   status = mu_mailbox_close (mbox);
   if (status)
     {
-      mu_diag_output (MU_DIAG_ERROR, _("closing mailbox failed: %s"), mu_strerror (status));
+      mu_diag_output (MU_DIAG_ERROR,
+		      _("closing mailbox failed: %s"), mu_strerror (status));
       msg = "closing mailbox failed";
     }
   mu_mailbox_destroy (&mbox);
@@ -56,3 +56,47 @@ imap4d_close (struct imap4d_command *command, char *arg MU_ARG_UNUSED)
     return util_finish (command, RESP_NO, msg);
   return util_finish (command, RESP_OK, "Completed");
 }
+
+/*
+6.4.2.  CLOSE Command
+
+   Arguments:  none
+
+   Responses:  no specific responses for this command
+
+   Result:     OK - close completed, now in authenticated state
+               NO - close failure: no mailbox selected
+               BAD - command unknown or arguments invalid
+
+   The CLOSE command permanently removes from the currently selected
+   mailbox all messages that have the \\Deleted flag set, and returns
+   to authenticated state from selected state.  */
+int
+imap4d_close (struct imap4d_command *command, imap4d_tokbuf_t tok)
+{
+  return imap4d_close0 (command, tok, 1);
+}
+
+/* RFC 3691:
+   
+2.  UNSELECT Command
+
+   Arguments:  none
+
+   Responses:  no specific responses for this command
+
+   Result:     OK - unselect completed, now in authenticated state
+               BAD - no mailbox selected, or argument supplied but
+                     none permitted
+
+      The UNSELECT command frees server's resources associated with the
+      selected mailbox and returns the server to the authenticated
+      state.  This command performs the same actions as CLOSE, except
+      that no messages are permanently removed from the currently
+      selected mailbox.
+*/
+int
+imap4d_unselect (struct imap4d_command *command, imap4d_tokbuf_t tok)
+{
+  return imap4d_close0 (command, tok, 0);
+}
