@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002, 2005, 
-   2006, 2007 Free Software Foundation, Inc.
+   2006, 2007, 2008 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -31,7 +31,7 @@ extern "C" {
 #define __s_cat3__(a,b,c) a ## b ## c
 #define SIEVE_EXPORT(module,name) __s_cat3__(module,_LTX_,name)
 
-typedef struct sieve_machine *mu_sieve_machine_t;
+typedef struct mu_sieve_machine *mu_sieve_machine_t;
 
 typedef struct
 {
@@ -191,7 +191,8 @@ int mu_sieve_tag_lookup (mu_list_t taglist, char *name,
 int mu_sieve_load_ext (mu_sieve_machine_t mach, const char *name);
 int mu_sieve_match_part_checker (const char *name, mu_list_t tags,
 				 mu_list_t args);
-
+int mu_sieve_match_part_checker (const char *name, mu_list_t tags,
+				 mu_list_t args);
 /* Operations in value lists */
 mu_sieve_value_t *mu_sieve_value_get (mu_list_t vlist, size_t index);
 int mu_sieve_vlist_do (mu_sieve_value_t * val, mu_list_action_t * ac,
@@ -255,6 +256,9 @@ const char *mu_sieve_type_str (mu_sieve_data_type type);
 /* Principal entry points */
 
 int mu_sieve_compile (mu_sieve_machine_t mach, const char *name);
+int mu_sieve_compile_buffer (mu_sieve_machine_t mach,
+			     const char *buf, int bufsize,
+			     const char *fname, int line);
 int mu_sieve_mailbox (mu_sieve_machine_t mach, mu_mailbox_t mbox);
 int mu_sieve_message (mu_sieve_machine_t mach, mu_message_t message);
 int mu_sieve_disass (mu_sieve_machine_t mach);
